<?php
/**
 * @package     over
 * @version     1.0
 * @author      NanoAgency
 * @link        http://www.nanoagency.co
 * @copyright   Copyright (c) 2016 NanoAgency
 * @license     GPL v2
 */

/*  Setup Theme ===================================================================================================== */
add_action( 'after_setup_theme', 'ovez_theme_setup' );
if ( ! function_exists( 'ovez_theme_setup' ) ) :
    function ovez_theme_setup() {
        load_theme_textdomain( 'ovez', get_template_directory() . '/languages' );

        //  Add default posts and comments RSS feed links to head.
        add_theme_support( 'automatic-feed-links' );

        //  Let WordPress manage the document title.
        add_theme_support( 'title-tag' );

        //  Enable support for Post Thumbnails on posts and pages.
        add_theme_support( 'post-thumbnails' );

        set_post_thumbnail_size( 825, 510, true );

        add_image_size( 'thumb-image', 600, 450, true);

        //Enable support for Post Formats.
        add_theme_support( 'html5', array(
            'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
        ) );

        add_theme_support( 'post-formats', array(
            'aside', 'image', 'video', 'quote', 'link', 'gallery', 'status', 'audio', 'chat'
        ) );

        add_theme_support( 'custom-header' );

        add_theme_support( 'custom-background' );

        add_theme_support( "title-tag" );

        add_theme_support( 'woocommerce' );

        // Indicate widget sidebars can use selective refresh in the Customizer.
        add_theme_support( 'customize-selective-refresh-widgets' );

        add_theme_support( 'wp-block-styles' );

        add_theme_support( 'responsive-embeds' );

        add_theme_support( 'align-wide' );

        add_theme_support( 'editor-color-palette', array(
            array(
                'name' => esc_html__( 'strong magenta', 'ovez' ),
                'slug' => 'strong-magenta',
                'color' => '#a156b4',
            ),
            array(
                'name' => esc_html__( 'light grayish magenta', 'ovez' ),
                'slug' => 'light-grayish-magenta',
                'color' => '#d0a5db',
            ),
            array(
                'name' => esc_html__( 'very light gray', 'ovez' ),
                'slug' => 'very-light-gray',
                'color' => '#eee',
            ),
            array(
                'name' => esc_html__( 'very dark gray', 'ovez' ),
                'slug' => 'very-dark-gray',
                'color' => '#444',
            ),
        ) );
    }
endif;

/* Thumbnail Sizes ================================================================================================== */
set_post_thumbnail_size( 220, 150, true);

//layout blog
add_image_size( 'ovez-blog-sidebar', 90, 90, true);
add_image_size( 'ovez-related-image',370,247,true);
add_image_size( 'ovez-blog-list', 770 ,420, true);
add_image_size( 'ovez-blog-grid', 768 ,490, true);
add_image_size( 'ovez-blog-tran', 370 ,370, true);

//layout sub-cate
add_image_size( 'ovez-category-thumb-large', 770, 400,true );
add_image_size( 'ovez-category-thumb', 370, 400,true );
add_image_size( 'ovez-category-thumb-wide', 1170, 300,true );
add_image_size( 'ovez-category-thumb-vertical', 600, 645,true );

//layout detail
add_image_size( 'ovez-product-horizontal', 670, 600,true );
add_image_size( 'ovez-product-horizontal-small', 168, 150,true );
add_image_size( 'ovez-product-grid', 345, 345,true );
add_image_size( 'ovez-product-large', 1000, 820,true );

//layout product scattered shop
add_image_size( 'ovez-scattered-thumbnail-size', 470, 620,true );
add_image_size( 'ovez-scattered-sm-thumbnail-size', 370, 420,true );

//banner category scattered
add_image_size( 'ovez-scattered-horizontal', 670, 420,true );
add_image_size( 'ovez-scattered-square', 370, 320,true );
add_image_size( 'ovez-trans-lg-thumbnail-size', 650, 650,true );


/* Setup Font ======================================================================================================= */
function ovez_font_url() {
    $fonts_url = '';
    $roboto    = _x( 'on', 'Roboto font: on or off', 'ovez' );
    if ( 'off' !== $roboto ) {
        $font_families = array();
        if ( 'off' !== $roboto) {
            $font_families[] = 'Roboto:300,300i,400,400i,500,700';
        }
        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
        );
        $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
    }
    return esc_url_raw( $fonts_url );
}


/* Load Front-end scripts  ========================================================================================== */
add_action( 'wp_enqueue_scripts', 'ovez_theme_scripts');
function ovez_theme_scripts() {

    // Add  fonts, used in the main stylesheet.
    wp_enqueue_style( 'ovez-fonts', ovez_font_url(), array(), null );

    //register style CSS
    wp_enqueue_style('bootstrap-css',get_template_directory_uri().'/assets/css/bootstrap.min.css', array(), '3.0.2 ');
    wp_enqueue_style('ionicons-font',get_template_directory_uri().'/assets/css/plugins/ionicons.min.css', array(), '2.0.0 ');
    wp_enqueue_style('awesome-css',get_template_directory_uri().'/assets/css/plugins/font-awesome.min.css', array(), '4.6.3');
    wp_enqueue_style('slick-css',get_template_directory_uri().'/assets/css/plugins/slick.min.css', array(), '1.0.0');
    wp_enqueue_style('slick-theme',get_template_directory_uri().'/assets/css/plugins/slick-theme.min.css', array(), '1.0.0');
    wp_enqueue_style('slicknav-css',get_template_directory_uri().'/assets/css/plugins/slicknav.min.css', array(), '1.0.3');
    wp_enqueue_style('photoswipe-css',get_template_directory_uri().'/assets/css/plugins/photoswipe.min.css', array(), null);
    wp_enqueue_style('photoswipe-skin',get_template_directory_uri().'/assets/css/plugins/photoswipe-skin/default-skin.css', array(), null);
    wp_enqueue_style('jquery-ui', get_template_directory_uri() . '/inc/customize/assets/css/jquery-ui.min.css', array(),null);

    //style MAIN THEME
    wp_enqueue_style( 'ovez-main', get_template_directory_uri(). '/style.css', array(), null );
    //style SKIN THEME
    wp_enqueue_style('ovez-css', get_template_directory_uri().'/assets/css/style-default.min.css' );

    //register all plugins JS
    wp_enqueue_script( 'bootstrap-js', get_template_directory_uri().'/assets/js/plugins/bootstrap.min.js', array(), '2.2.0', true );
    wp_enqueue_script( 'html5-js', get_template_directory_uri().'/assets/js/plugins/html5.min.js', array(), '2.2.0', true );
    wp_enqueue_script( 'skip-link-focus', get_template_directory_uri().'/assets/js/plugins/skip-link-focus-fix.min.js', array(), '2.2.0', true );
    wp_enqueue_script( 'lazy-js', get_template_directory_uri().'/assets/js/plugins/jquery.lazy.js', array(), '2.2.0', true );

    wp_enqueue_script( 'slicknav-js', get_template_directory_uri().'/assets/js/plugins/jquery.slicknav.min.js', array(), '2.2.0', true );//menu
    wp_enqueue_script( 'slick-js', get_template_directory_uri().'/assets/js/plugins/slick.min.js', array(), '2.2.0', true ); //slick

    wp_enqueue_script('jquery-masonry');
    wp_enqueue_script( 'isotope-js', get_template_directory_uri().'/assets/js/plugins/isotope.pkgd.min.js', array(), '2.2.0', true );
    wp_enqueue_script( 'imagesloaded-js', get_template_directory_uri().'/assets/js/plugins/imagesloaded.pkgd.min.js', array(), '2.2.0', true );

    wp_register_script( 'parallax-js', get_template_directory_uri().'/assets/js/plugins/parallax.min.js', array(), '1.1.3', true ); //parallax
    wp_register_script( 'videoController', get_template_directory_uri().'/assets/js/plugins/jquery.videoController.min.js', array(), '2.2.0', true );//video



    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }

    if ( is_singular() && wp_attachment_is_image() ) {
        wp_enqueue_script( 'ovez-theme-keyboard-image-navigation', get_template_directory_uri() . '/assets/js/keyboard-image-navigation.min.js', array( 'jquery' ), '20141010' );
    }
    if( function_exists('is_product') && is_product()){
        wp_enqueue_script( 'wc-add-to-cart-variation' ); //woo
        wp_enqueue_script( 'photoswipe-js', get_template_directory_uri().'/assets/js/plugins/photoswipe.min.js', array(), null, true );
        wp_enqueue_script( 'photoswipe-ui-default', get_template_directory_uri().'/assets/js/plugins/photoswipe-ui-default.min.js', array(), null, true );

        wp_register_script( 'ovez-slick', get_template_directory_uri().'/assets/js/dev/ovez-slick.js', array('jquery'),null, true );
    }

    //jquery MAIN THEME
    wp_enqueue_script('ovez-isotope', get_template_directory_uri() . '/assets/js/dev/ovez-isotope.js', array('jquery'),null, true);
    wp_enqueue_script('ovez-main', get_template_directory_uri() . '/assets/js/dev/ovez.js', array('jquery'),null, true);

}

/* Load Back-end SCRIPTS============================================================================================= */
function ovez_js_enqueue()
{
    wp_enqueue_media();
    wp_enqueue_style('thickbox');
    wp_enqueue_script('media-upload');
    wp_enqueue_script('thickbox');
    // moved the js to an external file, you may want to change the path
    wp_enqueue_script('information-js',get_template_directory_uri(). '/assets/js/widget.min.js', 'jquery', '1.0', true);
}
add_action('admin_enqueue_scripts', 'ovez_js_enqueue');

/* Register the required plugins    ================================================================================= */
add_action( 'tgmpa_register', 'ovez_register_required_plugins' );
function ovez_register_required_plugins() {

    $plugins = array(
        // This is an example of how to include a plugin pre-packaged with a theme.
        array(
            'name'      => esc_html__( 'Nano Core Plugin', 'ovez' ),
            'slug'      => 'theme-core',
            'source'    => get_template_directory() . '/inc/theme-plugins/theme-core.zip',
            'required'  => true,
            'version'   => '1.0.2',
            'force_activation' => false,
            'force_deactivation' => false,
            'image_url' => get_template_directory_uri() . '/inc/backend/assets/images/plugins/nano.jpg',

        ),
        //WooSwatches
        array(
            'name'      =>  esc_html__('WooSwatches - WooCommerce Color or Image Variation Swatches', 'ovez' ),
            'slug'      => 'woocommerce-colororimage-variation-select',
            'required'  => false,
            'source'    => get_template_directory() . '/inc/theme-plugins/woocommerce-colororimage-variation-select.zip',
            'version'   => '2.7.10',
            'image_url' => get_template_directory_uri() . '/inc/backend/assets/images/plugins/wooswatches.jpg',
        ),
        //Slider Revolution
        array(
            'name'      =>  esc_html__('Slider Revolution', 'ovez' ),
            'slug'      => 'revslider',
            'source'    => get_template_directory() . '/inc/theme-plugins/revslider.zip',
            'required'  => false,
            'version'   => '5.4.8',
            'image_url' => get_template_directory_uri() . '/inc/backend/assets/images/plugins/revolution.jpg',
        ),
        //WPBakery Page Builder
        array(
            'name'      =>  esc_html__('WPBakery Page Builder', 'ovez' ),
            'slug'      => 'js_composer',
            'source'    => get_template_directory() . '/inc/theme-plugins/js_composer.zip',
            'required'  => true,
            'version'   => '6.0.5',
            'image_url' => get_template_directory_uri() . '/inc/backend/assets/images/plugins/vc.jpg',
        ),
        //Contact form 7
        array(
            'name'      => esc_html__('Contact Form 7', 'ovez' ),
            'slug'      => 'contact-form-7',
            'required'  => false,
            'image_url' => get_template_directory_uri() . '/inc/backend/assets/images/plugins/contact-form7.jpg',
        ),
        //MailChimp for WordPress
        array(
            'name'      =>  esc_html__('MailChimp for WordPress ', 'ovez' ),
            'slug'      => 'mailchimp-for-wp',
            'required'  => false,
            'image_url' => get_template_directory_uri() . '/inc/backend/assets/images/plugins/mailchimp.jpg',
        ),
        //Instagram
        array(
            'name'      =>  esc_html__('Instagram Feed', 'ovez' ),
            'slug'      => 'instagram-feed',
            'required'  => false,
            'image_url' => get_template_directory_uri() . '/inc/backend/assets/images/plugins/instagram.jpg',
        ),
        //woocommerce
        array(
            'name'      =>  esc_html__('WooCommerce', 'ovez' ),
            'slug'      => 'woocommerce',
            'required'  => false,
            'image_url' => get_template_directory_uri() . '/inc/backend/assets/images/plugins/woo.jpg',
        ),

        //YITH  Wishlist
        array(
            'name'      =>  esc_html__('YITH WooCommerce Wishlist', 'ovez' ),
            'slug'      => 'yith-woocommerce-wishlist',
            'required'  => false,
            'image_url' => get_template_directory_uri() . '/inc/backend/assets/images/plugins/yith.jpg',
        ),
        //Advanced Woo Search
        array(
            'name'      =>  esc_html__('Advanced Woo Search', 'ovez' ),
            'slug'      => 'advanced-woo-search',
            'required'  => false,
            'image_url' => get_template_directory_uri() . '/inc/backend/assets/images/plugins/ad-search.jpg',
        ),
        //Loco Translate
        array(
            'name'      =>  esc_html__('Loco Translate', 'ovez' ),
            'slug'      => 'loco-translate',
            'required'  => false,
            'image_url' => get_template_directory_uri() . '/inc/backend/assets/images/plugins/loco.jpg',
        ),
        //Classic Editor
        array(
            'name'      =>  esc_html__('Classic Editor', 'trebol' ),
            'slug'      => 'classic-editor',
            'required'  => false,
        ),

    );

    $config = array(
        'id'           => 'ovez',                   // Unique ID for hashing notices for multiple instances of TGMPA.
        'default_path' => '',                       // Default absolute path to pre-packaged plugins.
        'has_notices'  => true,
        'menu'         => 'tgmpa-install-plugins',  // Menu slug.
        'dismiss_msg'  => '',                       // If 'dismissable' is false, this message will be output at top of nag.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'is_automatic' => true,                     // Automatically activate plugins after installation or not.
        'message'      => '',                       // Message to output right before the plugins table.

    );

    tgmpa( $plugins, $config );

}

/* Register Navigation ============================================================================================== */
register_nav_menus( array(
    'primary_navigation'    => esc_html__( 'Primary Navigation', 'ovez' ),
    'top_navigation'        => esc_html__( 'Topbar Navigation', 'ovez' ),
    'shop_navigation'       => esc_html__( 'Shop Navigation', 'ovez' ),
) );

/* Register Sidebar ================================================================================================= */
if ( function_exists('register_sidebar') ) {
    register_sidebar( array(
        'name'          => esc_html__( 'Archive', 'ovez' ),
        'id'            => 'archive',
        'description'   => esc_html__( 'Add widgets here to appear in your sidebar for the Archive.', 'ovez' ),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h2 class="widgettitle">',
        'after_title'   => '</h2>',
    ) );
    register_sidebar( array(
        'name'          => esc_html__( 'Shop', 'ovez' ),
        'id'            => 'shop',
        'description'   => esc_html__( 'Add widgets here to appear in your sidebar for the Shop', 'ovez' ),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h2 class="widgettitle">',
        'after_title'   => '</h2>',
    ) );

    register_sidebar( array(
        'name'          => esc_html__( 'Sidebar ', 'ovez' ),
        'id'            => 'sidebar-1',
        'description'   => esc_html__( 'This is custom sidebar in Home Page, you can get it in the home page.', 'ovez' ),
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h2 class="widgettitle">',
        'after_title'   => '</h2>',
    ) );
    register_sidebar(array(
        'name' => esc_html__('Footer 1','ovez'),
        'id'   => 'footer-1',
        'description'   => esc_html__( 'Add the widget here to appear in the first Footer column.', 'ovez' ),
        'before_widget' => '<div id="%1$s" class="widget last %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h2 class="widgettitle">',
        'after_title' => '</h2>',
    ));
    register_sidebar(array(
        'name' => esc_html__('Footer 2','ovez'),
        'id'   => 'footer-2',
        'description'   => esc_html__( 'Add the widget here to appear in the second Footer column.', 'ovez' ),
        'before_widget' => '<div id="%1$s" class="widget last %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h2 class="widgettitle">',
        'after_title' => '</h2>',
    ));
    register_sidebar(array(
        'name' => esc_html__('Footer 3','ovez'),
        'id'   => 'footer-3',
        'description'   => esc_html__( 'Add the widget here to appear in the 3rd Footer column.', 'ovez' ),
        'before_widget' => '<div id="%1$s" class="widget first %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h2 class="widgettitle">',
        'after_title' => '</h2>',
    ));
    register_sidebar(array(
        'name' => esc_html__('Range Footer','ovez'),
        'id'   => 'footer-hoz',
        'description'   => esc_html__( 'Add the widget here to appear in the Range Footer column.', 'ovez' ),
        'before_widget' => '<div id="%1$s" class="widget first %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h2 class="widgettitle">',
        'after_title' => '</h2>',
    ));
    register_sidebar(array(
        'name' => esc_html__('Topbar Left','ovez'),
        'id'   => 'topbar-left',
        'before_widget' => '<div id="%1$s" class="widget last %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h2 class="widgettitle">',
        'after_title' => '</h2>',
    ));
}